==> haskell-wai-3.2.2.1-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai
version: 3.2.2.1
id: wai-3.2.2.1-L0mqQcd6qdzCEAAdCddmDK
key: wai-3.2.2.1-L0mqQcd6qdzCEAAdCddmDK
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
stability: Stable
homepage: https://github.com/yesodweb/wai
synopsis: Web Application Interface.
description:
    Provides a common protocol for communication between web applications and web servers.
    .
    API docs and the README are available at <http://www.stackage.org/package/wai>.
category: Web
abi: 9399fbb7c681f208b0ecfd53e795e8e5
exposed: True
exposed-modules:
    Network.Wai Network.Wai.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/wai-3.2.2.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/wai-3.2.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/wai-3.2.2.1
hs-libraries: HSwai-3.2.2.1-L0mqQcd6qdzCEAAdCddmDK
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    http-types-0.12.3-2tcDIAoQ8De6A4nb7F3Iw
    network-2.8.0.0-LvSlvEKiGr81Yl4BCXERfa text-1.2.3.1
    transformers-0.5.6.2 vault-0.3.1.3-8BGTZ7EAtzu96Sn1MTnrVy
haddock-interfaces: /usr/share/doc/haskell-wai/html/wai.haddock
haddock-html: /usr/share/doc/haskell-wai/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-3.2.2.1-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai
version: 3.2.2.1
id: wai-3.2.2.1-D4By6E5iDCC22X0Chwq66q
key: wai-3.2.2.1-D4By6E5iDCC22X0Chwq66q
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
stability: Stable
homepage: https://github.com/yesodweb/wai
synopsis: Web Application Interface.
description:
    Provides a common protocol for communication between web applications and web servers.
    .
    API docs and the README are available at <http://www.stackage.org/package/wai>.
category: Web
abi: 9733e48db91a54478ac2f3587d8f1eb3
exposed: True
exposed-modules:
    Network.Wai Network.Wai.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/wai-3.2.2.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/wai-3.2.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/wai-3.2.2.1
hs-libraries: HSwai-3.2.2.1-D4By6E5iDCC22X0Chwq66q
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    http-types-0.12.3-DXhLFpEBHd8LSYPoefsPrf
    network-2.8.0.1-L17Rv8Nouqq1qZnRto8DBo text-1.2.3.1
    transformers-0.5.6.2 vault-0.3.1.3-LVX2SJ2biUv8APLWYfdzlf
haddock-interfaces: /usr/share/doc/haskell-wai/html/wai.haddock
haddock-html: /usr/share/doc/haskell-wai/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
